@@ -46,7 +46,7 @@ class {package_name}Conan(Sense2File):
        "Depends": parseRequires2Denpends(requires),
        "Homepage": "www.example.com",
     }}
-    deb_changelog = "my changelog"
+    deb_changelog = "{name} changelog"
     # deb_install_path = ""
     
     ## user and channel for uploading cpp package to artifactory
