@@ -134,11 +134,22 @@ def _create_deb_file(conanfile):
     add_lib_cmd = "cp -r lib " + app_folder + "/lib "
     if os.path.exists("lib"):
         conanfile.run(add_lib_cmd)
-    
+        output.success("add lib folder in the package into deb_file")
+
     add_bin_cmd = "cp -r bin " + app_folder + "/bin "
     if os.path.exists("bin"):
         conanfile.run(add_bin_cmd)
-
+        output.success("add bin folder in the package into deb_file")
+        
+    add_share_cmd = "cp -r share " + app_folder + "/share"
+    add_include_cmd = "cp -r include " + app_folder + "/include"
+    if os.path.exists("share"):
+        conanfile.run(add_share_cmd)
+        output.success("add share folder in the package into deb_file")
+        if os.path.exists("include"):
+            conanfile.run(add_include_cmd)
+            output.success("add include folder in the package into deb_file")
+        
     ## generate deb package in build
     build_package_cmd = "dpkg-deb --build " + deb_folder + " " + deb_file
     conanfile.run(build_package_cmd)
